MPESA APIs
==========

The django-daraja library supports the different MPESA APIs exposed by the Daraja platform. These are the supported APIs:

.. toctree::
   :maxdepth: 2

   oauth
   stk_push
   b2c_payment
